==> daas-fss-mongodb-1.0.2-sources.jar: in/clouthink/daas/fss/mongodb/model/FileObjectHistory.java <==
package in.clouthink.daas.fss.mongodb.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.DBRef;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.Date;

/**
 * Created by dz on 16/3/29.
 */
@Document(collection = "FileObjectHistories")
public class FileObjectHistory implements in.clouthink.daas.fss.core.FileObjectHistory {

	@Id
	private String id;

	@JsonIgnore
	@Indexed
	@DBRef(lazy = true)
	private FileObject fileObject;

	@Indexed
	private String finalFilename;

	private String originalFilename;

	private String prettyFilename;

	private String contentType;

	private String uploadedBy;

	private Date uploadedAt;

	private int version;

	@Override
	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	@Override
	public FileObject getFileObject() {
		return fileObject;
	}

	public void setFileObject(FileObject fileObject) {
		this.fileObject = fileObject;
	}

	@Override
	public String getFinalFilename() {
		return finalFilename;
	}

	public void setFinalFilename(String finalFilename) {
		this.finalFilename = finalFilename;
	}

	@Override
	public String getOriginalFilename() {
		return originalFilename;
	}

	public void setOriginalFilename(String originalFilename) {
		this.originalFilename = originalFilename;
	}

	@Override
	public String getPrettyFilename() {
		return prettyFilename;
	}

	public void setPrettyFilename(String prettyFilename) {
		this.prettyFilename = prettyFilename;
	}

	@Override
	public String getContentType() {
		return contentType;
	}

	public void setContentType(String contentType) {
		this.contentType = contentType;
	}

	@Override
	public String getUploadedBy() {
		return uploadedBy;
	}

	public void setUploadedBy(String uploadedBy) {
		this.uploadedBy = uploadedBy;
	}

	@Override
	public Date getUploadedAt() {
		return uploadedAt;
	}

	public void setUploadedAt(Date uploadedAt) {
		this.uploadedAt = uploadedAt;
	}

	@Override
	public int getVersion() {
		return version;
	}

	public void setVersion(int version) {
		this.version = version;
	}
}

==> daas-fss-mongodb-2.0.0-sources.jar: in/clouthink/daas/fss/mongodb/model/FileObjectHistory.java <==
package in.clouthink.daas.fss.mongodb.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.DBRef;
import org.springframework.data.mongodb.core.mapping.Document;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

/**
 * @author dz
 */
@Document(collection = "FileObjectHistories")
public class FileObjectHistory implements in.clouthink.daas.fss.core.FileObjectHistory {

	public static FileObjectHistory from(FileObject fileObjectImpl) {
		FileObjectHistory result = new FileObjectHistory();
		result.setFileObject(fileObjectImpl);
		result.setFinalFilename(fileObjectImpl.getFinalFilename());
		result.setOriginalFilename(fileObjectImpl.getOriginalFilename());
		result.setPrettyFilename(fileObjectImpl.getPrettyFilename());

		result.setContentType(fileObjectImpl.getContentType());
		result.setUploadedBy(fileObjectImpl.getUploadedBy());
		result.setUploadedAt(fileObjectImpl.getUploadedAt());
		result.setVersion(fileObjectImpl.getVersion());
		result.setSize(fileObjectImpl.getSize());
		result.setAttributes(fileObjectImpl.getAttributes());
		return result;
	}

	@Id
	private String id;

	@JsonIgnore
	@Indexed
	@DBRef(lazy = true)
	private FileObject fileObject;

	@Indexed
	private String finalFilename;

	private String originalFilename;

	private String prettyFilename;

	private String contentType;

	private String uploadedBy;

	private Date uploadedAt;

	private long size;

	private int version;

	private Map<String,String> attributes = new HashMap<String,String>();

	@Override
	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	@Override
	public FileObject getFileObject() {
		return fileObject;
	}

	public void setFileObject(FileObject fileObject) {
		this.fileObject = fileObject;
	}

	@Override
	public String getFinalFilename() {
		return finalFilename;
	}

	public void setFinalFilename(String finalFilename) {
		this.finalFilename = finalFilename;
	}

	@Override
	public String getOriginalFilename() {
		return originalFilename;
	}

	public void setOriginalFilename(String originalFilename) {
		this.originalFilename = originalFilename;
	}

	@Override
	public String getPrettyFilename() {
		return prettyFilename;
	}

	public void setPrettyFilename(String prettyFilename) {
		this.prettyFilename = prettyFilename;
	}

	@Override
	public String getContentType() {
		return contentType;
	}

	public void setContentType(String contentType) {
		this.contentType = contentType;
	}

	@Override
	public String getUploadedBy() {
		return uploadedBy;
	}

	public void setUploadedBy(String uploadedBy) {
		this.uploadedBy = uploadedBy;
	}

	@Override
	public Date getUploadedAt() {
		return uploadedAt;
	}

	public void setUploadedAt(Date uploadedAt) {
		this.uploadedAt = uploadedAt;
	}

	@Override
	public int getVersion() {
		return version;
	}

	public void setVersion(int version) {
		this.version = version;
	}

	@Override
	public long getSize() {
		return size;
	}

	public void setSize(long size) {
		this.size = size;
	}

	@Override
	public Map<String,String> getAttributes() {
		return attributes;
	}

	public void setAttributes(Map<String,String> attributes) {
		this.attributes = attributes;
	}
}
